module.exports = function(grunt){
  var backendModules = ['../backend/gen', '../backend/vendor/teknisa/pebLibraries'];
  
  grunt.initConfig({
    buildEnvironment: {
  		development: {
  			configFile: "../backend/parameters/devEnvironment.json"
  		},
  		production: {
  			configFile: "../backend/parameters/prodEnvironment.json"
  		},
  		test: {
  			configFile: "../backend/parameters/testEnvironment.json"
  		},
  		srcFolders: ["../backend/config", "./", "./assets/json", "./js/", "./", "../backend"]
  	},
    zhIdGenerator: {
      options: {
        jsonPath: ['../'],
        menuPath: ["../menu.json"],
        replaceIds: false
      }
    },
    zhWords: {
      options: {
          serverUrl: "https://translate.teknisa.com/backend/index.php",
          wordsPath: "./public/metadata/json/words/",
          organization: "20",
          project: "114788"
      }
    },
  });
  
  function buildFileContent(srcFiles, filePath, directory) {
        var parts = filePath.split('/');
        parts.shift();
        parts.shift();
        var filename = parts[parts.length - 1];
        var extension = filename.split('.').pop().toUpperCase();
        if (extension == 'JSON' || extension == 'XML') {
            if (directory == 'datasources') {
                filename = parts.pop();
                filename = filename.replace(/\.[^/.]+$/, "");
                srcFiles[directory][filename] = './../' + parts.join('/');
            } else {
                srcFiles[directory].push('/../' + parts.join('/'));
            }
        }
    }

  grunt.registerTask('backendStep', 'build backend config files', function () {
    var srcFiles = {
      config: [],
      datasources: {}
    };
    var directories = ['config', 'datasources'];
    var dest = {
      config: '../backend/config/servicesMapping.json',
      datasources: '../backend/config/dataSourcesMapping.json'
    };
    directories.forEach(function (directory) {
      backendModules.forEach(function (module) {
        var moduleParts = module.split('/');
        var moduleName = moduleParts[moduleParts.length - 1].toUpperCase();
        var subModules = grunt.file.expand({
          filter: 'isDirectory'
        }, module + '/src/Teknisa/' + moduleName + '/Modules/*');

        subModules.forEach(function (subModule) {
          grunt.file.expand({
              filter: 'isFile'
          }, subModule + '/' + directory + '/**/*').forEach(function (filePath) {
              buildFileContent(srcFiles, filePath, directory);
          });
        });

        grunt.file.expand({
          filter: 'isFile'
        }, module + '/' + directory + '/**/*').forEach(function (filePath) {
          buildFileContent(srcFiles, filePath, directory);
        });
      });
    });
    grunt.file.write(dest.config, JSON.stringify(srcFiles.config, null, 2));
    grunt.file.write(dest.datasources, JSON.stringify(srcFiles.datasources, null, 2));
  });

  grunt.loadNpmTasks('grunt-zh-environment-builder');
  grunt.loadNpmTasks('grunt-zh-id-generator');
  grunt.loadNpmTasks('grunt-zh-words');

  grunt.registerTask('default', ['zhIdGenerator', 'buildEnvironment', 'backendStep', 'zhWords']);
};
